package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````@"$```````!``````````)`!`0``
M`````````$``.``)`$``&@`9``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````,B:````````R)H`````````
M``$```````$````&````:/L```````!H^P$``````&C[`0``````&`4`````
M``!`%0```````````0```````@````8```!X^P```````'C[`0``````>/L!
M```````0`@```````!`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````Q),```````#$DP```````,23````````_`````````#\``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````&C[````````:/L!``````!H^P$`
M`````)@$````````F`0````````!`````````"]L:6(O;&0M;&EN=7@M86%R
M8V@V-"YS;RXQ```$````%`````,```!'3E4`JIIA[$C(Z"'QQ@FZ/(!B6/Z'
MDO<$````$`````$```!'3E4```````,````'`````````!$```!*````!```
M``@````A$!``!<`$A"@"$`6`AD"$@@D`!`D@!(B(@!!!N@`""$H```!+````
M3@```%(```!3````6P```%P```!=`````````%\```!@````80```&(```!C
M````9@```````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[;49-1\=E0\E"'_
MY`[9<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RQ8[Y=YNN.2?/NA;&!K"4/69Z_,
M9D)%U>R)!W#3,V+;[16,)<P-.I<+?ZF<F^"G`@IJ&IY0O]I7&Z/@^TD`````
M`````````````````````````````````P`+`#@;````````````````````
M`````P`6`````@`````````````````H`@``$@``````````````````````
M``#8````$@````````````````````````#%`@``$@``````````````````
M``````#N````$0`````````````````````````/`@``$@``````````````
M``````````"B`@``$@````````````````````````"2`0``$@``````````
M``````````````#<`0``$@`````````````````````````!````(```````
M```````````````````Y`0``$@````````````````````````!V`0``$@``
M``````````````````````"T`P``$@````````````````````````!:`@``
M$@````````````````````````#R`@``$0````````````````````````"U
M`@``$@````````````````````````!]`0``$@``````````````````````
M``!8`0``$@````````````````````````!N`0``$@``````````````````
M``````!C`@``$@````````````````````````"Y````$@``````````````
M``````````!&````(@`````````````````````````0````(```````````
M``````````````"U`0``$@````````````````````````!``@``$@``````
M```````````````````L````(`````````````````````````#?````$@``
M``````````````````````":````$@````````````````````````"C````
M$@````````````````````````"J````$@````````````````````````"&
M`@``$0````````````````````````!G````$@``````````````````````
M```R`@``$@`````````````````````````-`0``$@``````````````````
M``````#+`0``$@````````````````````````#H````$@``````````````
M```````````H`0``$@````````````````````````!+`@``$@``````````
M``````````````"N`0``$@````````````````````````!U`@``$@``````
M``````````````````!M````$@````````````````````````"J`@``$@``
M``````````````````````"-`@``$@````````````````````````!)`0``
M$@````````````````````````!_````$@`````````````````````````:
M`@``$@`````````````````````````(`@``$@``````````````````````
M``#F`@``$@````````````````````````"B````$@``````````````````
M``````"9`0``$@````````````````````````#Y````$@``````````````
M``````````"@`0``$@````````````````````````"Q````$@``````````
M``````````````"+`0``$@````````````````````````#1`@``$@``````
M``````````````````"$`0``$@````````````````````````#\`0``$@``
M``````````````````````!O`@``$@````````````````````````!"`0``
M$@````````````````````````#O`0``$0`````````````````````````M
M`@``$@`````````````````````````=`0``$@``````````````````````
M``"\`0``$@````````````````````````!F`0``$@``````````````````
M``````"O`@``$@````````````````````````!5````$@``````````````
M``````````"0````$0````````````````````````";`@``$@``````````
M``````````````##````$@````````````````````````#*````$@``````
M``````````````````"2````$0````````````````````````!H`@``$@``
M```````````````````````/!```$``7`*@0`@````````````````"]`P``
M$@`-`&1%````````-`$````````T!```$@`-`$1)````````@`<```````!B
M````$@`-`$`?````````)`(````````T`P``$@`-```[````````!```````
M``!2`P``$@`-`,10````````;`(```````#E`P``$``7`(```@``````````
M``````!:!```$@`-``0[````````'`(````````:!```$``7`(```@``````
M``````````!%`P``$@`-`"`]````````*`````````!H`P``$@`-`#1#````
M````D`````````#)`P``$0`/`%!3````````!`````````#S`P``$@`-`*!&
M````````"`$```````#^`P``$@`-`.`Y````````.``````````&!```$``7
M`*@0`@`````````````````O!```$``7`*@0`@````````````````!(!```
M$@`-`.1#````````+`$```````#8`P``$``6`````@````````````````",
M`P``$@`-`%`]````````&`$```````!!!```$``6`(```@``````````````
M``!G!```$0`6`'@``@``````"`````````#>`P``$@`-`(`A````````-```
M```````F!```$@`-`!!%````````5`````````#:`P``(``6`````@``````
M``````````"B`P``$@`-`,1#````````(`````````!V`P``$@`-`"`Z````
M````X`````````"8`P``$@`-`+!'````````E`$````````.!```$``7`*@0
M`@````````````````!Q!```$@`-`'`^````````Q`0`````````7U]G;6]N
M7W-T87)T7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G
M:7-T97)434-L;VYE5&%B;&4`7U]C>&%?9FEN86QI>F4`7U]L:6)C7W-T87)T
M7VUA:6X`86)O<G0`7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9F%I
M;`!?7V5N=FER;VX`<W1R;F-M<`!L<W1A=#8T`&%C8V5S<P!O<&5N9&ER`')E
M861D:7(V-`!S=')L96X`7U]S<')I;G1F7V-H:P!U;FQI;FL`8VQO<V5D:7(`
M<FUD:7(`4$Q?=&AR7VME>0!P=&AR96%D7V=E='-P96-I9FEC`&)O;W1?1'EN
M84QO861E<@!097)L7VYE=UA3`%!E<FQ?;F5W6%-?9FQA9W,`<F5A9&QI;FL`
M;65M8VAR`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?<W9?<V5T<'8`;65M;6]V90!R
M96%L;&]C`&=E='!I9`!M96UC<'D`<W1R8VAR`'-T<F1U<`!S=')T;VL`<W1R
M8VUP`%]?<W1R;F-P>5]C:&L`9V5T=6ED`'-T<G-T<@!097)L7W-Y<U]I;FET
M,P!097)L7V%T9F]R:U]L;V-K`%!E<FQ?871F;W)K7W5N;&]C:P!03%]D;U]U
M;F1U;7``4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?<&%R<V4`<&5R;%]D97-T
M<G5C=`!P97)L7V9R964`4&5R;%]S>7-?=&5R;0!P97)L7V%L;&]C`'!E<FQ?
M8V]N<W1R=6-T`'!E<FQ?<G5N`&5X:70`;65M<V5T`&UK9&ER`%]?97)R;F]?
M;&]C871I;VX`<W1D97)R`%]?9G!R:6YT9E]C:&L`;W!E;C8T`&QS965K-C0`
M<F5A9`!C;&]S90!097)L7V=V7V9E=&-H<'8`4&5R;%]G971?<W8`4&5R;%]C
M<F]A:U]N;V-O;G1E>'0`4&5R;%]M9U]S970`7U]S=&%C:U]C:&M?9W5A<F0`
M;&EB<&5R;"YS;RXU+C,T`&QI8F,N<V\N-@!L9"UL:6YU>"UA87)C:#8T+G-O
M+C$`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS
M7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C
M`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`
M7U]B<W-?<W1A<G1?7P!S:&%?=7!D871E`'AS7VEN:70`7U]E;F1?7P!?7V)S
M<U]E;F1?7P!?7V)S<U]S=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M:W1M<&1I
M<@!?961A=&$`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A
M<E]P;`!P87)?:6YI=%]E;G8`1TQ)0D-?,BXQ-P!'3$E"0U\R+C,T`$=,24)#
M7S(N,S,```````````$``@`!``$``0`"``(``0`!``(``@`"``$``P`!``(`
M`0`"``(``@`"``$``@`!``$``@`"``0``@`"``(``0`!``$``@`!``$``@`"
M``(``@`"``$``@`!``(``0`$``(`!0`"``(``@`!``(``0`"``(``0`"``$`
M`0`"``(`!0`"``(``@`"``(``@`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$````!``$`'@,``!``
M```@````EY&6!@```P!^!`````````$``P`4`P``$`````````"TD98&```%
M`(D$```0````LY&6!@``!`"4!```$````)>1E@8```(`?@0```````!H^P$`
M``````,$````````D"(```````!P^P$```````,$````````0"(```````"@
M_P$```````,$````````Q%````````#H_P$```````,$````````>``"````
M``#X_P$```````,$````````0!\````````(``(```````,$````````"``"
M```````8``(```````,$````````L),````````@``(```````,$````````
MP%,````````P``(```````,$````````L%0````````X``(```````,$````
M````D),```````!```(```````,$````````F),```````!(``(```````,$
M````````H),```````!0``(```````,$````````J),```````!@``(`````
M``,$````````>),```````!H``(```````,$````````@),```````!X``(`
M``````,$````````R%8```````"(_P$```````$$```&``````````````"0
M_P$```````$$```*``````````````"8_P$```````$$```+````````````
M``"H_P$```````$$```0``````````````"P_P$```````$$```7````````
M``````"X_P$```````$$```8``````````````#`_P$```````$$```;````
M``````````#(_P$```````$$```@``````````````#0_P$```````$$```C
M``````````````#8_P$```````$$```D``````````````#@_P$```````$$
M```]``````````````#P_P$```````$$``!(``````````````"@_0$`````
M``($```#``````````````"H_0$```````($```$``````````````"P_0$`
M``````($```%``````````````"X_0$```````($```'``````````````#`
M_0$```````($```(``````````````#(_0$```````($```)````````````
M``#0_0$```````($```+``````````````#8_0$```````($```,````````
M``````#@_0$```````($```-``````````````#H_0$```````($```.````
M``````````#P_0$```````($```/``````````````#X_0$```````($```1
M````````````````_@$```````($```2```````````````(_@$```````($
M```3```````````````0_@$```````($```4```````````````8_@$`````
M``($```5```````````````@_@$```````($```6```````````````H_@$`
M``````($```7```````````````P_@$```````($```9```````````````X
M_@$```````($```:``````````````!`_@$```````($```<````````````
M``!(_@$```````($```=``````````````!0_@$```````($```>````````
M``````!8_@$```````($```?``````````````!@_@$```````($```A````
M``````````!H_@$```````($```B``````````````!P_@$```````($```E
M``````````````!X_@$```````($```F``````````````"`_@$```````($
M```G``````````````"(_@$```````($```H``````````````"0_@$`````
M``($```I``````````````"8_@$```````($```J``````````````"@_@$`
M``````($```K``````````````"H_@$```````($```L``````````````"P
M_@$```````($```M``````````````"X_@$```````($```N````````````
M``#`_@$```````($```O``````````````#(_@$```````($```P````````
M``````#0_@$```````($```Q``````````````#8_@$```````($```R````
M``````````#@_@$```````($```S``````````````#H_@$```````($```T
M``````````````#P_@$```````($```U``````````````#X_@$```````($
M```V````````````````_P$```````($```W```````````````(_P$`````
M``($```X```````````````0_P$```````($```Y```````````````8_P$`
M``````($```Z```````````````@_P$```````($```[```````````````H
M_P$```````($```\```````````````P_P$```````($```^````````````
M```X_P$```````($```_``````````````!`_P$```````($``!`````````
M``````!(_P$```````($``!!``````````````!0_P$```````($``!"````
M``````````!8_P$```````($``!#``````````````!@_P$```````($``!%
M``````````````!H_P$```````($``!&``````````````!P_P$```````($
M``!'``````````````!X_P$```````($``!)```````````````?(`/5_7N_
MJ?T#`)&<`0"4_7O!J,`#7];P>[^I\```T!'.1OD08C:1(`(?UA\@`]4?(`/5
M'R`#U?```-`1TD;Y$((VD2`"'];P``#0$=9&^1"B-I$@`A_6\```T!':1OD0
MPC:1(`(?UO```-`1WD;Y$.(VD2`"'];P``#0$>)&^1`"-Y$@`A_6\```T!'F
M1OD0(C>1(`(?UO```-`1ZD;Y$$(WD2`"'];P``#0$>Y&^1!B-Y$@`A_6\```
MT!'R1OD0@C>1(`(?UO```-`1]D;Y$*(WD2`"'];P``#0$?I&^1#"-Y$@`A_6
M\```T!'^1OD0XC>1(`(?UO```-`1`D?Y$`(XD2`"'];P``#0$09'^1`B.)$@
M`A_6\```T!$*1_D00CB1(`(?UO```-`1#D?Y$&(XD2`"'];P``#0$1)'^1""
M.)$@`A_6\```T!$61_D0HCB1(`(?UO```-`1&D?Y$,(XD2`"'];P``#0$1Y'
M^1#B.)$@`A_6\```T!$B1_D0`CF1(`(?UO```-`1)D?Y$"(YD2`"'];P``#0
M$2I'^1!".9$@`A_6\```T!$N1_D08CF1(`(?UO```-`1,D?Y$((YD2`"'];P
M``#0$39'^1"B.9$@`A_6\```T!$Z1_D0PCF1(`(?UO```-`1/D?Y$.(YD2`"
M'];P``#0$4)'^1`".I$@`A_6\```T!%&1_D0(CJ1(`(?UO```-`12D?Y$$(Z
MD2`"'];P``#0$4Y'^1!B.I$@`A_6\```T!%21_D0@CJ1(`(?UO```-`15D?Y
M$*(ZD2`"'];P``#0$5I'^1#".I$@`A_6\```T!%>1_D0XCJ1(`(?UO```-`1
M8D?Y$`([D2`"'];P``#0$69'^1`B.Y$@`A_6\```T!%J1_D00CN1(`(?UO``
M`-`1;D?Y$&([D2`"'];P``#0$7)'^1"".Y$@`A_6\```T!%V1_D0HCN1(`(?
MUO```-`1>D?Y$,([D2`"'];P``#0$7Y'^1#B.Y$@`A_6\```T!&"1_D0`CR1
M(`(?UO```-`1AD?Y$"(\D2`"'];P``#0$8I'^1!"/)$@`A_6\```T!&.1_D0
M8CR1(`(?UO```-`1DD?Y$((\D2`"'];P``#0$99'^1"B/)$@`A_6\```T!&:
M1_D0PCR1(`(?UO```-`1GD?Y$.(\D2`"'];P``#0$:)'^1`"/9$@`A_6\```
MT!&F1_D0(CV1(`(?UO```-`1JD?Y$$(]D2`"'];P``#0$:Y'^1!B/9$@`A_6
M\```T!&R1_D0@CV1(`(?UO```-`1MD?Y$*(]D2`"'];P``#0$;I'^1#"/9$@
M`A_6\```T!&^1_D0XCV1(`(?U@````````````````````#]>[JIXP``T/T#
M`)%CU$?Y\U,!J?5;`JGBAP.IXN,`D>$#`9'@3P"YX#,!D60`0/GD+P#Y!`"`
MTL[__Y?@``#0X@``T`#L1_E"R$?YX0,"JN@,`)3@``#0`/!'^0``0#D`"@`T
M\P``\/0``-"4QD?Y@`)`N9/__Y<"*%(Y0@`?,@(H$CF``D"YCO__E^$#`*KB
M3T"Y0!``$50,`!$B*%(Y`'Q]DT(``#(B*!(YG?__E^,#`*KB``#082("D>8C
M0/D```#P1/1'^0!`%)'E3T"Y`@``\,<`0/E"(!21A`!`^6<(`*DC"`#Y9``!
MJ;\$`'$-"0!4(0"`TB`,`!'$>&'X(00`D638(/B_``%K;/__5*4,`!%U(@*1
M?]@E^.(#%"H!``"P!`"`TB'0&)&@!D#YS/[_E_0#`"K`!``T=2("D?93`9&@
M!D#Y2O__EP```/#A`Q:J```1D:,$`)0@!`"T<R("D6`&0/FR_O^7%?__E^``
M`+``U$?YXB]`^0$`0/E"``'K`0"`TL$$`%3@`Q0J\U-!J?5;0JG]>\:HP`-?
MUO#^_Y?S``#08B("D4`$`/E``P"T]```L`[__Y>`QD?Y``!`N3___Y<?W"@Y
MJ/__%Z`&0/F__O^7]`,`*MC__Q>@#D#Y8```M`\)`)3=__\7X0,6J@```/``
M(`^1>@0`E*`.`/G@^O^T!PD`E-7__Q>%`(!2P/__%R``@%+!_O^7$/__EQ\@
M`]4?(`/5'R`#U1\@`]4?(`/5'R`#U1\@`]4?(`/5'0"`TAX`@-+E`P"JX0-`
M^>(C`)'F`P"1X```L`#\1_D#`(#2!`"`TDW__Y?0_O^7X```L`#,1_E```"T
MA/[_%\`#7]8?(`/5'R`#U>```-````*1X0``T"$``I$_``#KP```5.$``+`A
MW$?Y80``M/`#`:H``A_6P`-?UN```-````*1X0``T"$``I$A``#+(OQ_TT$,
M@8LA_$&3P0``M.(``+!"X$?Y8@``M/`#`JH``A_6P`-?UA\@`]7]>[ZI_0,`
MD?,+`/GS``#08`)".4`!`#7@``"P`-A'^8```+3@``#0``1`^87^_Y?8__^7
M(`"`4F`"`CGS"T#Y_7O"J,`#7]8?(`/5'R`#U=S__Q<?(`/5'R`#U1\@`]7_
M@PK1X0``L.)C`)$%X`"1".`!D>0#`JK]>P"I_0,`D2'41_DC`$#YXT\!^0,`
M@-*A`$"YA$``D:.$0/@A",!:@0`?^&'\8--G_&C3YQQXDB;<>-,A'`A3QAQP
MDN/@0ZHA``:J(0`#JH&`'_@?`07K`?[_5$4`")%!`$#Y0B``D4,$0/E$'$#Y
M8P`!RD$P0/DA``3*(0`#RB/\7]-A!`&J(7Q`DD$\`/E?``7K8?[_5`<H0*DD
M,X_2""1!J410J_+EFT&I(W2=TN+\6]/L_$+30A0'JHQY!ZHA`0C*(]NM\B$`
M"HHA``G*I0`$BR)`(HM!_4+3(7@*JD(`!8L+$$#Y+7Q`DJ4!",K&``2+0@`+
M"Z4`!XJE``C*(0`,RD[\6]-/_$+3I0`)B\X5`JJE``:+(0`"BN)Y`JJE``X+
MYK]"J2$`#<JN_%O3(0`(B\X5!:JP_$+3Q@`$B^\!!(LA``:+A@$"RB$`#@N,
M?4"2Q@`%BL8`#,HN_%O3Q@`-B\X5`:H->@6JQ@`/B\8`#@M%``W*[A]`^4)\
M0)*E``&*,/Q"TZ4``LK.`02+I0`,B\_\6],,>@&J[Q4&JJ$!#,JE``Z+[B-`
M^:4`#PNM?4"2(0`&BB$`#<K/_$+3YGD&JB$``HO"`02+KOQ;TR$``HNO_$+3
M@@$&RLX5!:HN``X+0@`%BN5Y!:J,?4"2X;]$J4(`#,I"``V+S?U;TZT5#JK0
M?$"2(0`$BT(``8O!``7*30`-"R$`#HHA`!#*QOU"T^(!!(O.>`ZJ(0`,BZS]
M6].F?$"2(0`"BXP5#:JB``[*I?U"TR\`#`NE>`VJ0@`-BN&W1:E"``;*0@`0
MB^S]6].,%0^J\/U"TR$`!(M"``&+P0$%RB$`#XK.?4"2(0`.RDP`#`L/>@^J
MH@$$BR$`!HN&_5O3(0`"BZ(`#\I"``R*I7Q`DD(`!<K&%`RJ0@`.BRT`!@OP
MNT:IAOU"T\9X#*JA_5O3+!0-JN$!!LHA``V*[WU`DB$`#\H0`@2+(0`%BT(`
M$(NP_4+33``,"PUZ#:K"`02+(0`"B\(`#<I"``R*QGQ`DD(`!LJ%_5O30@`/
MBZ44#*KPOT>I+@`%"X7]0M.E>`RJP?U;TRP4#JJA`07*(0`.BJU]0)(0`@2+
M(0`-RD(`$(O0_4+33``,"PYZ#JKB`02+(0`&BR$``HNB``[*0@`,BJ5\0))"
M``7*AOU;TT(`#8O&%`RJ\+=(J2\`!@N&_4+3QG@,JN']6],L%`^JP0$&RB$`
M#XK.?4"2$`($BR$`#LI"`!"+\/U"TTP`#`L/>@^JH@$$BR$`!8LA``*+P@`/
MRD(`#(K&?$"20@`&RH7]6]-"``Z+I10,JO"[2:DM``4+A?U"TZ5X#*JA_5O3
M+!0-JN$!!<HA``V*[WU`DA`"!(LA``_*0@`0B[#]0M-,``P+#7H-JL(!!(LA
M``:+(0`"BZ(`#<J&_5O3I7Q`DD(`#(K&%`RJ0@`%RBX`!@M"``^+AOU"T^&_
M2JG,>`RJQOU;T\84#JHA``2+Y`$$BT(``8NA`0S*(0`.BJU]0)(A``W*S_U"
MT](``@ON>0ZJ(0`%BT9`)HOO7T#Y(0`$BX0!#LI%_EO3A``&2N(!`XNE%!*J
MA``-BTW^0M.P``$+LGD2JH0``HOB8T#Y)4`EB\$!$LH&_EO3)0`%2L84$*I!
M``.+HD`LBPS^0M//``0+C7D0JD(``8OA9T#YAD`FBT0"#<KE_5O3A``&2J44
M#ZHF``.+@4`NB[$``@LA``:+[/U"TT5`)8OF:T#YCWD/JJ(!#\HD_EO310`%
M2H04$:K"``.+)OY"TY```0O1>!&JYF]`^21`)(OA`1'*K$`RBR0`!$H%_EO3
M@@$"BZ44$*K!``.+#/Y"TX9`+8NN``(+D'D0JL$``8OF<T#Y14`EBR("$,K$
M_5O30@`%2H04#JK&``.+0D`OB\S]0M.-``$+CGD.JD(`!HOF=T#Y)$`DBP$"
M#LJE_5O3(0`$2J44#:K&``.+(4`QBZ\``@LA``:+K/U"TT5`)8OF>T#YC7D-
MJL(!#<KD_5O3A!0/JD4`!4K"``.+YOU"TY$``0O/>`^JYG]`^21`)(NA`0_*
MK$`PBR0`!$HE_EO3@@$"BZ44$:K!``.++/Y"TX9`+HNP``(+C'D1JL$``8OF
M@T#Y14`EB^(!#,H$_EO30@`%2H04$*K&``.+0D`MBPW^0M..``$+0@`&BZ9Y
M$*KPAT#Y)$`DBX$!!LK%_5O3(0`$2J44#JH0`@.+(4`OBZT``@LA`!"+S_U"
MTT5`)8OPBT#Y[GD.JL(`#LJD_5O3A!0-JD4`!4H"`@.+L/U"TX\``0L->@VJ
M\(]`^21`)(O!`0W*K$`LBR0`!$KE_5O3I10/JH9`)HL!`@.+\/U"T\$``8N"
M`0*+!GH/JJP``@M%0"6+H@$&RD(`!4J$_5O30D`NBX[]0M.$%`RJS'D,JO`[
M4JF/``$+)$`DB\$`#,KE_5O3(0`$2J44#ZHA0"V+[?U"TQ`"`XNO>0^J0@`0
MB\X!`XNP``(+14`EB^V;0/F"`0_*!/Y;TT(`!4HA``Z+A!00JJ4!`XM"0":+
M#?Y"TXX``0M%``6+HGD0JO"?0/DD0"2+X0$"RL;]6],D``1*QA0.J@$"`XN$
M0"R+T/U"T\T`!0N$``&+`7H.JO"C0/FF0":+10`!RJS]6].E``9*C!4-JA`"
M`XNE0"^+K_U"TXX!!`OO>0VJI0`0B_"G0/F,0"R+)``/RL;]6].,``Q*QA0.
MJ@0"`XN"02*+S/U"T\T`!0M"``2+A'D.JJ9`)HOE`03*I0`&2J[]0M.P_5O3
MH4`ABQ`6#:K%>0VJ[#=5J4(`$`M._$+3A@$#BT/\6]-C%`*JC``%JB$`!HN,
M`0**(0`#"Z,`!`J,`0.JAIN7TF;CL?+">0*J@T$OBZP!!HLM_%O38P`,BZT5
M`:JL``*J[K-`^6,`#0N,`0&*30`%"HP!#:HO_$+3X7D!JLX!!HN$022+;?Q;
MTZT5`ZI,``&JA``.BXP!`XKNMT#YA``-"RT``@IO_$+3C`$-JLX!!HN-_%O3
MA4$EB^QY`ZJE``Z+HQ4$JBT`#*KNNT#YHP`#"Z4!!(J-`0$*C_Q"TZ4`#:K.
M`0:+I4`BBVW\6]/B>02JK14#JH0!`JJE``Z+A``#BNZ_0/FE``T+30`,"F_\
M0M.$``VJS@$&BX1`(8NM_%O3X7D#JJT5!:J$``Z+0P`!JH0`#0LN``(*[<-`
M^6,`!8JO_$+38P`.JN5Y!:JM`0:+8T`LBX[\6]/.%02J+``%JF,`#8N,`02*
M[<=`^6,`#@NN``$*C`$.JH[\0M."02*+K`$&BVW\6]/$>02JK14#JD(`#(M"
M``T+K``$JNW+0/F.``4*C`$#BF_\0M.,`0ZJXWD#JJT!!HN!02&+3OQ;TXP`
M`ZK.%0*J(0`-BR$`#@N,`0**;@`$"HP!#JI._$+3PGD"JH5!)8OMNUFI+_Q"
MTZP!!HLM_%O3K14!JJ4`#(ML``*JI0`-"XP!`8I-``,*C`$-JN%Y`:K.`0:+
MA$$DBZW\6]-,``&JK14%JH0`#HONUT#YA``-"XP!!8HM``(*C`$-JJ_\0M/.
M`0:+@T$CBXW\6]/L>06JK14$JB4`#*IC``Z+I0`$BN[;0/EC``T+C0$!"H_\
M0M.E``VJY'D$JLX!!HNB0"*+;?Q;TX4!!*JM%0.J0@`.B^[?0/E"``T+I0`#
MBHT`#`IO_$+3I0`-JLX!!HNA0"&+3?Q;T^5Y`ZJM%0*J@P`%JB$`#HM._$+3
M(0`-"V,``HK">0*JKP`$"NT[7*EC``^J;$`LBR/\6]-C%`&J+_Q"TZT!!HN,
M`0V+K0`"JH,!`PNL`0&*30`%"N%Y`:J,`0VJ;?Q;TX1!)(O,`0:+A``,BTP`
M`:HN``(*C`$#BHP!#JJM%0.JA4$EBX0`#0OO,UVI;?Q"TZUY`ZJ._%O3SA4$
MJN\!!HNC``^+)0`-JF,`#@NE``2*K@$!"J4`#JJ._$+3Q'D$JJ)`(HN%`0:+
M;/Q;TXP5`ZI"``6+;OQ"TZ4!!*I"``P+I0`#BL-Y`ZJ/``T*[#M>J:4`#ZJE
M0"&+0?Q;TR$4`JI/_$+3C`$&BZ4`#(N,``.JI0`!"XP!`HIA``0*XGD"JHP!
M`:I0``,*@4$MB\T!!HNL_%O3(0`-BXP5!:IM``*J[_M`^8X!`0NM`06*+$`L
MBZT!$*K0_4+3I$$DB^T!!HNO_$+3QOU;TX0`#8O&%`ZJ[7D%JM(`!`OO_T#Y
M00`-RB$`#$K%.IC214RY\B%`(XOL`06+0_Y;TPYZ#JHA``R+8Q02JH9`)HOL
M`T'Y<0`!"Z0!#LHC0".+A``&2H8!!8N"0"*+3/Y"TR3^6].2>1*J0@`&BX04
M$:KF!T'YD``""\$!$LI$0"2+(P`#2L$`!8ML0"V+)OY"TP/^6]/1>!&JC`$!
MBV,4$*KA"T'Y;P`,"T("$<J#02.+1``$2B(`!8N&0"Z+X?U;TP3^0M/&``*+
MD'@0JB$4#ZKB#T'Y+@`&"R0"$,KL_4+3A``#2D,`!8N$0#*+POU;TX]Y#ZJ$
M``.+0A0.JL%`(8OC$T'Y30`$"P8"#\K,_4+3P0`!2F8`!8LC0#&+H?U;TXYY
M#JIC``:+(10-JH)`(HOF%T'Y,@`#"^0!#LIA0"&+@@`"2L0`!8M,0#"+IOU"
MTT+^6]/->`VJA`$$BT(4$JKF&T'Y40`$"\,!#<I,_D+380`!2L,`!8LF0"^+
M(?Y;T\,``XN,>1*J(101JH)`(HOF'T'Y,``#"Z0!#,IA0"&+@@`"2L8`!8M$
M0"Z++OY"TP+^6].$``:+0A00JL9Y$:KN(T'Y3P`$"X,!!LJ"0"*+80`!2LX!
M!8LC0"V+#?Y"T^']6].P>1"J8P`.BR$4#ZKN)T'Y+0`#"\0`$,IA0"&+@@`"
M2L0!!8M,0"R+[OU"TZ+]6]//>0^JA`$$BT(4#:KL*T'Y3@`$"P,"#\J"0"*+
M80`!2H,!!8LF0":+K/U"T\']6]/#``.+(10.JH9Y#:KL+T'Y+0`#"^0!!LIA
M0"&+@@`"2HP!!8M$0#"+T/U"TZ+]6],.>@ZJA``,BT(4#:KL,T'Y40`$"\,`
M#LJ"0"*+80`!2HP!!8LC0"^+K_U"TR'^6]/M>0VJ8P`,BR$4$:KL-T'Y,``#
M"\0!#<HO_D+3@@`"2H0!!8M,0":+`OY;TX8!!(M"%!"J['D1JF%`(8OD.T'Y
M3P`&"Z,!#,K"0"*+80`!2H,`!8LD0"Z+#OY"T^']6].$``.+(10/JL-Y$*KP
M/T'Y+@`$"X8!`\J!0"&+P@`"2A`"!8M&0"V+[?U"T\+]6].O>0^J0A0.JL8`
M$(OM0T'Y4``&"V0`#\K&0"*+A``!2J$!!8N,0"R+S?U"TP3^6].,`0&+A!00
MJJYY#JKA1T'Y@@`,"^T!#LKG0"^+K0$&2B8`!8NC02.+0?Q;TR$4`JIC``:+
M8P`!"P'^0M/M2T'Y(7@0JH9!)(O0`0'*9/Q;T^P``)`/`@9*A!0#JJ8!!8M%
M_$+3Q@`'BZ)X`JJ'U4?YA``/BR$`"0O%`0L+8P`*"X0`!@M"``@+!`P`J0($
M`:D%$`#YX$]!^>$`0/D```'K`0"`TH$``%3]>T"I_X,*D<`#7]:@^O^7_7N\
MJ?T#`)'S4P&I@`8`M/=C`ZGW`P"JX```D`#X1_D8`$#Y&`8`M/5;`JGV`P&J
M%0"`4N`"0#D?]`!Q!!A`>J$"`%03`T#YLP$`M+5^0)/T`QBJX@,5JN$#%ZK@
M`Q.J3_K_EX```#5@:G4X'_0`<0`"`%23CD#X\_[_M?5;0JGW8T.IX`,3JO-3
M0:G]>\2HP`-?UO4#%ZJ@'D`X'_0`<0080'JA__]4M0(72^;__Q>4`AC+M08`
MD7,"%8N4_D.3U`(`N>`#$ZKS4T&I]5M"J?=C0ZG]>\2HP`-?UA,`@-+I__\7
M$P"`TO=C0ZGF__\7_7NUJ>(``)#]`P"10M1'^?,+`/GAHP"1\P,`JD,`0/GC
M5P#Y`P"`TFGZ_Y<@`@`UX3M`N0(`E%(A#!02/Q!`<2000GJ@`0!4X0``D"'4
M1_GC5T#Y(@!`^6,``NL"`(#2@0$`5/,+0/G]>\NHP`-?U@``@%+U__\7X`,3
MJD$`@%(3^O^7'P``<>`7GQKO__\7/_K_EQ\@`]4?(`/5_7NSJ>$``)#]`P"1
M(=1'^2(`0/GB9P#Y`@"`TL```+3S4P&I\P,`J@$`0#EA`0`U\U-!J>```)``
MU$?YXF=`^0$`0/E"``'K`0"`TD$)`%3]>\VHP`-?UD;Z_Y?T`P"J@/[_M/=C
M`ZD7``#0^",!D?=B#9'U6P*IX`,4JM'Y_Y>`!0"T`4Q`.15,`)$_N`!Q@0``
M5*$&0#D!__\T'R`#U0!,0#D?N`!Q0`4`5.`#$ZIH^O^7]@,`JN`#%:IE^O^7
MP`(`"P`(`!$`?$"3$?K_E^4#%:KD`Q.JXP,7J@(`@)+U`P"J(0"`4E[Z_Y?A
M`QBJX`,5JLOY_Y<?!``QH```5.!;0+D`#!02'Q!`<>`"`%3@`Q6J;_G_E^`#
M%:HQ^O^7X`,4JJ?Y_Y?@^O^U'R`#U>`#%*JS^?^7X`,3JLGY_Y?S4T&I]5M"
MJ?=C0ZFZ__\7H`9`.1^X`'&A^O]4H`I`.<#X_S32__\7X`,5JJ7__Y?J__\7
M\U,!J?5;`JGW8P.IW/G_E_U[OJG]`P"1\PL`^?,``)!SQD?Y8`)`N>WY_Y=@
M`D"YZ_G_E^(``)`C``#0`0``T&/@#I%"Z$?Y(8`-D0SZ_Y=@`D"YXOG_E^(`
M`)`$``#0\PM`^80`&Y']>\*HXP,$JD+01_D!``#0!0"`4B$`#I&?^?\7'R`#
MU1\@`]4,"(+2_V,LR^,``)#B_X'2_7L`J?T#`)%CU$?Y\U,!J?0#`*KU6P*I
M]>,`D?8#`:I@`$#YX!\(^0``@-+A`Q6J````T`!@#I$Z^?^7'P``<8T"`%0#
M!`!1H<IC.*$$`#4#`@`T<WQ`D^`#%:KB`Q.JX06`4M?Y_Y=``0"TX```D`#$
M1_D``$"YLOG_E^,#$ZKB`Q6JX0,4JI+Y_Y<(```4X```D`#$1_D``$"YJ?G_
ME^(#%JKA`Q2J-OG_E^```)``U$?YXA](^0$`0/E"``'K`0"`TB$!`%0,"(+2
M_7M`J?-30:GU6T*I_V,LB\`#7];C`P`JW/__%W[Y_Y<?(`/5_7NZJ>(``)#]
M`P"1\U,!J?,#`*KT`P&J]5L"J?=C`ZE"U$?Y(`!`.4$`0/GA+P#Y`0"`TA_T
M`'&4%I2:X`,4JL3Y_Y?V`P"JX5,!D>`#$ZK)_O^70`@`M/4#`*J]^?^7WP(`
MZ^D&`%3X5X"Y]P``D!CS?=-@`D`Y'_0`<0080'I`#`!4Y`,3JH,<0#A_]`!Q
M9!A`>J'__U2$`!/+A'Q`D_?Z1_G`"@"1```$B_8"0/E8^?^7P&HX^,`"`+3A
M`D#YX`,3JB-H>/@!%$`X80``.3_T`'$D&$!ZX```5!\@`]4"%$`X8AP`.%_T
M`'%$&$!Z@?__5*$'@%(``(#2810`.()J8#AB:"`X``0`D:+__S7@``"0`-1'
M^>(O0/D!`$#Y0@`!ZP$`@-*A!P!4\U-!J?5;0JGW8T.I_7O&J,`#7]8!`(#2
M'R`#U8)J83BB:B$X(00`D:+__S7N__\7]P``D/EK!*G@^D?Y&@!`^4`#0/D`
M!0"TX`,:JA4`@%(?(`/5`8Q`^.(#%2JU!@`1H?__M4`,`!$`?'V3X0``L"*(
M0+DB`@`U(@"`4B*(`+D9^?^7^0,`JH`#`+2X?GV3X0,:JN(#&*I3^?^7X/I'
M^1D``/F@!@`1]5<`N3_;(/CY:T2II?__%^$#`*K@`QJJK?C_E_D#`*KA^D?Y
M(```^4`!`+2X?GV3\___%P0`@-*E__\7``*`TA4`@%+@__\7^6L$J?3X_Y?Y
M:T2INO__%Q\@`]7]>[^IX```D/T#`)$`Q$?Y``!`N0/Y_Y?]>\&HX@``D",`
M`-`!``#00NA'^6/@#I$A@`V1(_G_%Q\@`]4?(`/5#`J$TO]C+,O@``"0`0B"
MTOU[`*G]`P"1`-1'^?-3`:GS8R&+]1,`^?7C`)$4`(#2`0!`^>$G$/D!`(#2
M9?C_E^0#`"H%``#0`P``T*6@#I%CP`Z1(@""TB$`@%+@`Q.J)/G_E^`#$ZKA
M`Q6J`@""TE3X_Y>``?@W\P,`J@`$`!$`?$"3Q_C_E_0#`*K```"T<WY`D^$#
M%:KB`Q.J7?C_EY]J,SC@``"0`-1'^>(G4/D!`$#Y0@`!ZP$`@-(!`0!4X`,4
MJ@P*A-+]>T"I\U-!J?430/G_8RR+P`-?UJGX_Y?(__\7#!R"TO]C+,OB``"0
M_7L`J?T#`)%"U$?Y\U,!J?,#`:KU6P*IX5,!D?4#`*I#`$#YXV\(^0,`@-(`
M``#0`"`/D?C]_Y?T`P"JX06`4N`#%:J_^/^78`(`M.$#%:H```#0`&`/D1+_
M_Y?@`Q6JX0``D"'41_GC;TCY(@!`^6,``NL"`(#280P`5`P<@M+]>T"I\U-!
MJ?5;0JG_8RR+P`-?UN`#%:KW8P.IU?C_E_@#`*K@`Q.JGOC_EQ<``-#AH@^1
M__?_E_,#`*H`"@"T]F,#D?EK!*D:``#0&0``T%H##Y$YPP^18`)`.2`&`#2T
M``"TX0,3JN`#%*I]^/^7@`0`-.`#$ZJ^^/^7`@0`46'"(HMCRF(X?[P`<0$!
M`%3@`P(J0@0`43\``#EAPB*+8\IB.'^\`'%`__]4`0<`$2````L?_#]Q[`(`
M5.0#$ZKF`Q6JY0,9J@,``-!CX`^1`@""TB$`@%+@`Q:JJ?C_E^%C`9'@`Q:J
M%OC_EZ```#7@:T"Y``P4$A\@0'%@`@!4X:(/D0``@-+*]_^7\P,`JD#Z_[7W
M8T.I^6M$J:S__Q>4``"T@`)`.1^X`'&```!4\P,:JB``@%+=__\7@`9`.0#^
M_S3[__\7X`,6JB$`@%(`^/^78/W_->$#%JH```#0`&`/D:_^_Y?@`Q:J3?C_
ME_=C0ZGY:T2IFO__%_=C0ZF3__\7]V,#J?EK!*DA^/^7`@!`.>$#`*KB```T
M'R`#U2$$`)%?O`!Q`!"!FB(`0#F"__\UP`-?UA\@`]4?(`/58`@`M/U[OJG]
M`P"1\PL`^?,#`*H!`$`YH08`-&7X_Y<"!`#18@("BW\"`NNC``!4-```%$($
M`-%_`@+KX`$`5$``0#D?O`!Q8/__5'\"`NN"!0!40@0`T7\"`NO@``!40`!`
M.1^\`''@`0!40@0`T7\"`NMA__]48`)`.1^\`'%@`P!4\PM`^0```-#]>\*H
M`,`/D1/X_Q=``$`Y'[P`<8$``%1"!`#1?P("ZV/__U1"`!/+``"`TD$(`)$_
M!$#Q"`$`5.```+`$H`*10@0`D>$#$ZK@`P2J`P""TOGW_Y?S"T#Y_7O"J,`#
M7];S"T#Y````T/U[PJ@```^1^??_%W\"`NL!_?]4W/__%P```-````^1\_?_
M%Q\@`]4?(`/5_7NZJ>```)#]`P"1`-1'^?5;`JGU``"0\U,!J10``-#S4P&1
M]V,#J90"$)'Y(P#YM?I'^0$`0/GA+P#Y`0"`TN$#$ZK@`Q2J&_W_E^`!`+2B
M`D#YXU>`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#
M%*H-_?^78/[_M?4``)`4``#0E$(0D;7Z1_GA`Q.JX`,4J@7]_Y?@`0"TH@)`
M^>-7@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`Q2J
M]_S_EV#^_[7U``"0%```T)1B$)&U^D?YX0,3JN`#%*KO_/^7X`$`M*("0/GC
M5X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,4JN'\
M_Y=@_O^U]0``D!0``-"4HA"1M?I'^>$#$ZK@`Q2JV?S_E^`!`+2B`D#YXU>`
MN4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#%*K+_/^7
M8/[_M=4``/`4``"PEL(0D;7Z1_GA`Q.JX`,6JL/\_Y?@`0"TH@)`^>-7@+E`
M#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`Q:JM?S_EV#^
M_[76``#P%0``L+4"$9'6^D?YX0,3JN`#%:JM_/^7X`$`M,("0/GC5X"Y0`P#
MBP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,5JI_\_Y=@_O^U
MU@``\!4``+"W(@^1UOI'^>$#$ZK@`Q>JE_S_E^`!`+3"`D#YXU>`N4`,`XL!
M!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#%ZJ)_/^78/[_M=<`
M`/`6``"PV$(1D??Z1_GA`Q.JX`,8JH'\_Y?@`0"TX@)`^>-7@+E`#`.+`01`
M^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`QBJ<_S_EV#^_[78``#P
M%P``L/F"$9$8^T?YX0,3JN`#&:IK_/^7X`$`M`(#0/GC5X"Y0`P#BP$$0/E!
M>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,9JEW\_Y=@_O^UV0``\!@`
M`+`8PQ&1.?M'^>$#$ZK@`QBJ5?S_E^`!`+0B`T#YXU>`N4`,`XL!!$#Y07@C
M^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#&*I'_/^78/[_M=D``/`8``"P
M&&,/D3G[1_GA`Q.JX`,8JC_\_Y?@`0"T(@-`^>-7@+E`#`.+`01`^4%X(_CA
M_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`QBJ,?S_EV#^_[7A`Q.J````L```
M$I$L_/^7X0,`JF```+3@@A&12_W_E^$#$ZH```"P`&`2D23\_Y?A`P"J@```
MM````+``P!*10OW_E^$#$ZH```"P```3D1O\_Y?A`P"J8`(`M*`B#Y$Z_?^7
MP```\`#41_GB+T#Y`0!`^4(``>L!`(#280(`5(#"$)$!``"P\U-!J2&@$Y'U
M6T*I]V-#J?DC0/G]>\:H*OW_%^$#$ZH```"P`$`3D0/\_Y?A`P"J8/W_M,!"
M$9$B_?^7Z/__%YSV_Y?]>[VIP0``\/T#`)$AU$?Y\PL`^?,``)`B`$#YXA<`
M^0(`@-)@$D"Y'P0`,6`!`%3!``#P(=1'^>,70/DB`$#Y8P`"ZP(`@-(A`@!4
M\PM`^?U[PZC``U_6X9,`D0```+``0!&1X_O_E^$#`*H``(!2H0``M"``0#D?
MP`!Q!!A`>N`'GQI@$@"YZO__%WCV_Y?]>[^I_0,`D5WV_Y<,]O^70```M```
M0/G]>\&HP`-?UOU[O*G"``#P_0,`D4+41_GS4P&IX=,`D?5;`JD5``"PML(3
MD4,`0/GC'P#Y`P"`TO0#`*K@`Q:JPOO_EX```+0!`$`Y\P,`JL$!`#7```#P
M`-1'^>(?0/D!`$#Y0@`!ZP$`@-(A!@!4X0,4JJ#"$Y'S4T&I]5M"J?U[Q*C4
M_/\7X0,4J@KV_Y>``0"TP```\`#41_GB'T#Y`0!`^4(``>L!`(#2(00`5/-3
M0:GU6T*I_7O$J,`#7];@`Q2JF/;_E_4#`*K@`Q.JE?;_EZ`"`(L`"`"10O;_
ME^8#$ZH"`("2(0"`4N0#%*KS`P"J!0``L`,``+"EH`^18^`/D8SV_Y?"``#P
M0M1'^>`?0/E!`$#Y```!ZP$`@-*!``!4X0,3JN`#%JK3__\7)?;_E_U[OZD`
M$(#2_0,`D2GV_Y<?&`#Y)F"$TB5QE=+$GYO2PXZ*T@(^G-*FZ*SRI?F]\D07
ML_)#!J+R0GJX\@84`*D$#`&I`GP"J1]X`+G]>\&HP`-?UOU[O*G!``#P_0,`
MD2'41_GS4P&I]`,`JO5;`JDB`$#YXA\`^0(`@-+Q_?^7`0!`.?,#`*KA```T
M'R`#U0`$`)$_O`!Q<Q*`F@$`0#F!__\U]@``D)\"`/'U!Y\:P!)`N1\$`#&`
M!`!4'P``<>`'GQJU`@`*E0$`-<```/``U$?YXA]`^0$`0/E"``'K`0"`T@$%
M`%3S4T&I]5M"J?U[Q*C``U_6@`)`.8#^_S0!``"PX`,3JB$`%)&"`(#2J/7_
ME\#]_S7```#P`-1'^>(?0/D!`$#Y0@`!ZP$`@-*A`@!4X`,4JO-30:GU6T*I
M_7O$J)?[_Q<```"PX=,`D0!`$9$P^_^7H```M```0#D?P`!Q!!A`>F$``%3?
M$@"YU___%R``@%+`$@"YE?K_--[__Q?#]?^7'R`#U1\@`]7]>[RI0GQ`D_T#
M`)'S4P&I%.``D?,#`:KU6P*I]0,`JO8#`JKW8P.I!8Q"J0!X0+FD#`(+OP`$
MZV.4@YIB=$*+I(H"J:`#`#7?_@!QK04`5-8"`5'8?@93%P<`$?=J>M-W`A>+
M'R`#U6`&0*W@`Q6J@`8`K6`&0:US`@&1@`8!K>#V_Y=_`A?K`?__5-8:&$OA
M`Q>JX`,4JL)^0),]]?^7MGH`N?-30:GU6T*I]V-#J?U[Q*C``U_6%PB`4O<"
M`$O_`A9K@,(@B_?2EAKX?D"3X@,8JB_U_Y>@>D"YX`(`"Z!Z`+D?``%QX?W_
M5-8"%TMS`AB+X`,5JL+V_Y?3__\7]P,3JN/__Q<?(`/5'R`#U?U[O*GB#X`2
M_0,`D?-3`:GT`P"J\P,!JO5;`JDUX`"1]QL`^2`40/DV*$"Y-S!`N0`@`U/6
M"L!:`00`$?<*P%JBRB`XH,(ABS_@`'&-"0!4`@B`4D(``4L!`(!20GQ`D\3U
M_Y?@`Q.JHO;_EW\V`/D`!`!/H`(`K:`*@#W@`Q.J=UH.*9OV_Y=A`D#YX`,3
MJB'\6-.!`@`Y80)`^2'\4-.!!@`Y80)`^2'\2-.!"@`Y80)`^8$.`#EA!D#Y
M(?Q8TX$2`#EA!D#Y(?Q0TX$6`#EA!D#Y(?Q(TX$:`#EA!D#Y@1X`.6$*0/DA
M_%C3@2(`.6$*0/DA_%#3@28`.6$*0/DA_$C3@2H`.6$*0/F!+@`Y80Y`^2'\
M6-.!,@`Y80Y`^2'\4-.!-@`Y80Y`^2'\2-.!.@`Y80Y`^8$^`#EA$D#Y(?Q8
MTX%"`#EA$D#Y(?Q0TX%&`#EA$D#Y(?Q(TX%*`#EA$D#Y@4X`.?-30:GU6T*I
M]QM`^?U[Q*A:]?\7`@>`4D(``4L!`(!20GQ`DWGU_Y>[__\7##*0TO]C+,O!
M``#P_7L!J?U#`)$AU$?Y]V,$J?<``)#B0@"1\U,"J4.``)'U6P.I]@,`JO0S
M`I'Y:P6I^0,#D1@``+!$E$"I1AQ%J6`$0*UB",`]`P*0TN-C(XL@`$#Y8+P`
M^0``@-+A`Q2J0PQ`^0`C#Y%",$#Y(`<`K>8?":GB4P#YY)<*J>-?`/GB.X`]
M5/K_EX```+0!`$`Y\P,`J@$A`#7[<P:IU?3_EX3T_Y=`'`"T&@!`^1H<`+3@
M`QJJ/_7_EP#X?],`!`"1[/3_ET0#0#GU`P"JI`$`-!L``+#S`Q6J>X,4D1\@
M`]7@`Q.JXP,;J@(`@)(A`(!2-/7_EW,*`)%$'T`X)/__-0$``+`Y(P"1(,`2
MD0,``!0@AT#XX`D`M.$#%*HN^O^7\P,`JF#__[0!`$`Y(?__-&7Z_Y?@_O\T
MX`,3JNGT_Y?S`P"J8`@`M.`#$ZH9]?^7^0,`JN`#%:H6]?^7.P,`"WL3$!$:
M``"P>W]`D^`#&ZK`]/^7YP,5JN0#$ZI%PP^1!@``L`,``+#&`!218Z`4D0(`
M@)+Y`P"J(0"`4@GU_Y?@`QFJ`3B`4M[T_Y<?!``QH0``5)/T_Y<%`$"YOT0`
M<4$6`%3\PP.1X`,9JN$#'*JP]/^7\P,`*@`&`#3```#P`@``L,,"0/GD`QFJ
M`.1'^4+@%9$A`(!2%0"`T@``0/F,]/^7P```\`$"D-+B8R&+`-1'^4.\0/D!
M`$#Y8P`!ZP$`@-(A*@!4X`,5J@PRD-+]>T&I\U-"J?5;0ZGW8T2I^6M%J?MS
M1JG_8RR+P`-?UOJC`I$9`(!24]MY^+,!`+1@`D`Y8`$`-#D'`!'@`Q.J%?K_
MER#__S3@`Q.JF?3_E_,#`*H@]O^U4]MY^+/^_[43`(#2K?__%^`#0;D`#!02
M'Q!`<<'Y_U3U"T&Y4?3_E[\"`&M!^?]4X`-!N0`@`!(?``=QP?C_5.`#&ZII
M]/^7`0``L/4#`*H@0!>1X0,4JKWY_Y?A`P"JP!``M,`"0/FQ^_^7^P,`JD`0
M`+3@`QNJK/3_E^(#`*H?#`!Q+0(`5`!\0),!``"P`!``T2%@%Y%@`P"+XC\`
M^5[T_Y<@`0`UXC]`^5\0`''`&P!40!0`46#+8#@?O`!Q0!L`5!\@`]7@$D"Y
M'P0`,8`-`%06``"P@`X`-,!"$9$!``"P(:`3D;SZ_Y=:PP^1%```L)0"&Y$6
M``"PQ_/_E]8B&)'F`P`JYP,4JN4#&JKD`QFJX`,5J@,``+`"`("28^`7D2$`
M@%*$]/^7$0``%!+T_Y<``$"Y'T0`<4$"`%2V\_^7]`,`^7,&`!'F`P`JYP,3
M*N4#&JKD`QFJXP,6JN`#%:H"`("2(0"`4G/T_Y?@`Q6J`3B`4DCT_Y<?!``Q
M@/W_5.`#&:I,]/^7X0,5J@`C#Y&1^O^7X`,5JIS]_Y=W__\7\T,"D14`@%(?
M(`/58-IU^(`!`+3A`Q2JM08`$6/Y_Y=@__^T`0!`.2'__S0B]/^7^@,`JH#B
M_[5@VG7XP/[_M:`!@-(`]/^7&@``L/4#`*I:8Q219`J`4A/__Q?```#PY`,9
MJL,"0/D"``"P`.1'^4+@%)$A`(!2%0"`T@``0/GA\_^75?__%WC]_Y?```#P
M`@*0TN)C(HL`U$?Y0[Q`^0$`0/EC``'K`0"`TJ$4`%3@`Q.J##*0TOU[0:GS
M4T*I]5M#J?=C1*GY:T6I_V,LB_GS_Q?;`D#Y?O__%Q8``+#A`Q2JP$(1D3#Y
M_Y>@``"T``!`.1_``'$$&$!ZX0L`5/\2`+G@`QNJ`0"`4A8``+`9]/^7]`,`
M*@#Q_S1"`(!2(0*`DO8C!I%#\_^7X0,6JN`#%"K"`(#2K_/_E^`C1CF````U
MX"=&.1\,`7&`"P!4`@"`4@$`@-+@`Q0J-O/_EP`0@-*X\_^7\P,`JB1@A-(C
M<972PI^;TL&.BM(`/IS2I.BL\J/YO?)"%[/R00:B\D!ZN/)D#@"I8@8!J6!^
M`JE_&@#Y?WH`N04``!3B`P`JX0,6JN`#$ZK;_?^7X0,6JN`#%"H"`)#2B_/_
MEQ\``''L_O]4X`,4*O3#!9'>\_^7]@,4JN`#%*H;``"P]`,<JI>C`)%[@Q21
MX0,3J@[^_Y<?(`/5Q!9`..`#%*KC`QNJE`H`D0(`@)(A`(!2WO/_E_\"%.L!
M__]4Y@,<JD7##Y'D`QFJ!P``L`,``+#G`!N18Z`7D0(`@)(A`(!2X`,5JO]C
M!#G0\_^7X`,9JJ[S_Y?A`Q6J`",/D?/Y_Y?@`Q6J_OS_E]G^_Q<@`(!2X!(`
MN2[__Q?6!D#Y]N3_M.`#%JJ]\_^7'PP`\6GD_U0`$`#1`0``D,`"`(LA@!>1
M<O/_EQ\``'%[$Y::&___%^`K1CD?!`%Q8?3_5.`O1CD?#`%Q`?3_5.`S1CD?
M(`%QH?/_5.`W1CD?%`%Q0?/_5.`#%"I"`(!2(0>`DL_R_Y?A`Q:JX`,4*B(%
M@-([\_^7Y@,6JD7##Y'D`QFJX`,5J@<``)`#``"0YP`;D6.@%Y$"`("2(0"`
M4ICS_Y<J__\7.O/_E_MS!JDX\_^7_7N[J<$``-#]`P"1\U,!J=,``-#U6P*I
M]A,!D77&1_GW&P#Y(=1'^:`"0+DB`$#YXB<`^0(`@-)!\_^7]`,`JJ`"0+D^
M\_^7X@,`JH/"0CD```"0X0,6J@#`$)%#Q`(Y@/C_EX```+0!`$`Y/\0`<:`+
M`%1.^_^7=<9'^:`"0+DO\_^7`0``D&,`@%(A@!B1(@"`4K+R_Y?T`P"J@`$`
MM*`"0+DF\_^7@0I`^0(``)!"H!B1(0!`^;'R_Y>`"D#Y``!`^0`,0+E`"[`W
M=\9'^=4``/#@`D"Y&?/_EP$``)!C`(!2(<`8D2(`@%*<\O^7]`,`JL`!`+3A
M`Q:J````D`!@#Y%7^/^7X0)`N?<#`*K@`P$J]P<`M`GS_Y>!"D#YX@,7JB$`
M0/F5\O^7<\9'^;<B`I%@`D"Y`?/_E_0#`*I@`D"Y_O+_ER(`@%(!``"0(>`8
MD5[R_Y<"``"0X0,`JD)`&9'@`Q2JA?+_EV`"0+GS\O^7X@,`JN$#%JH```"0
M`"`/D5_$`CDV^/^7X`X`^?,#`*K@`@"T`3B`4N`#$ZH#\_^7`00`$3\$`'$$
MB%%ZX00`5,```-``U$?YXB=`^0$`0/E"``'K`0"`TN$#`%3S4T&I]5M"J?<;
M0/G]>\6HP`-?U@`$0#F`]/\THO__%^`*0/FC_?^7X`X`^?,#`*K`_/^U````
MD`!@&9'<\O^7R_+_EZ`B`I&""D#Y`0A`^4``0/DA`$#Y\?C_E\#__Q>@`D"Y
MPO+_EX$*0/DA`$#YL_+_EZ+__Q>E\O^7M2("D>,#`"KB`Q.J````D```&I&A
M"D#Y(0!`^<7R_Y?#``#P8P1`^8KR_Q<?(`/5_7N_J?T#`)']>\&HP`-?U@$`
M`@``````)7,O)7,```!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`````
M`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+W-E;&8O97AE``!E>&4`
M`````"]P<F]C+R5I+R5S```````N`````````%!!4E]414U0``````````!0
M05)?4%)/1TY!344`````.@`````````O`````````"5S)7,E<P``4$523#5,
M24(``````````%!%4DQ,24(`4$523#5/4%0``````````%!%4DQ)3P``4$%2
M7TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?0TQ%04X`````````
M4$%27T1%0E5'`````````%!!4E]#04-(10````````!005)?1TQ/0D%,7T1%
M0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@````````!005)?5$U01$E2
M````````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````````
M`#$`````````3$1?3$E"4D%265]0051(`'!A<BT`````+64````````M+0``
M`````%-94U1%30``)3`R>``````E<R5S)7,E<P``````````)7,Z(&-R96%T
M:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A
M9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N
M*0H```````!0051(`````'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E
M<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,``````````!@`
M````````<&5R;``````P`````````%!!4CHZ4&%C:V5R.CI615)324].````
M`#$N,#4U````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````
M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S
M<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN
M:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"10
M05)?34%'24,L("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO
M9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U
M:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I
M<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@
M(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@
M+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P
M87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G
M*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M
M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D
M:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I
M;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*
M>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E
M;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS
M;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN
M+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD
M(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD
M*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F
M;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["B1005)?
M34%'24,@/2`B7&Y005(N<&U<;B(["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@
M:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R
M7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY
M("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G
M.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\
M3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H
M)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R
M;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D[
M"E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B
M)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I
M.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL
M97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;
M0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@
M=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)
M0SL*?0IM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@
M)'-I>F4@/2`M<R!?1D@["FUY("1M86=I8U]P;W,@/2`D<VEZ92`M("1S:7IE
M("4@)&-H=6YK7W-I>F4[(",@3D]413H@)&UA9VEC7W!O<R!I<R!A(&UU;'1I
M<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*
M<V5E:R!?1D@L("1M86=I8U]P;W,L(#`["G)E860@7T9(+"`D8G5F+"`D8VAU
M;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I
M;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]
M("1I.PIL87-T.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*:68@
M*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S
M=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S
M="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I;VX@
M)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E
M860@7T9(+"`D8G5F+"`T.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U
M9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S
M970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@)&]F9G-E="P@,#L*
M)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@
M7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A
M9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR
M96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN
M9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M
M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D
M8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN
M*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E
M7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F
M=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?
M5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D
M97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I
M.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^
M("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E
M<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0[
M"GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@
M0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN
M9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN
M9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#
M3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]
M($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T
M96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN
M9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L
M<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M
M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*
M;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B
M0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U
M;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q
M=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME
M>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@
M/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*
M9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI
M>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PI]"G5N;&5S<R`H)&)U9B!E<2`B4$M<,#`S7#`P-"(I('L*;W5T<RAQ<5M.
M;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G
M;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&
M2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P
M87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA
M;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H
M4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U
M;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!
M4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I
M<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*
M=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R
M"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H
M:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8[
M"GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?
M:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB
M<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H
M($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@
M(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?
M87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*
M96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF
M("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E
M<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P
M96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@
M9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?
M;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES
M=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN
M8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@
M0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]
M"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@
M<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P
M96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD
M('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I
M.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&
M:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B
M73L*?0II9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G
M+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@
M)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R
M(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@(E!+7#`P,UPP
M,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)
M3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W
M-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=
M.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97([
M"FEF("AD969I;F5D("1D871A7W!O<RD@>PIR96%D(%]&2"P@)&QO861E<BP@
M)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R
M(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D
M97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE
M*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@
M0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@
M)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!]
M(&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)
M3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,[
M"B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE
M8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF
M:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_
M"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL
M97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]
M("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA
M;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H
M0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]
M?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-
M;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@
M/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R
M968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E
M;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ
M<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=
M.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I
M"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M
M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA
M<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B
M1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H
M(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N
M="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N
M=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T
M;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*
M?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"B1C86-H95]N86UE(#T@<W5B<W1R
M("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@
M)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z
M.E-(02T^;F5W*#$I.PIO<&5N(&UY("1T:"P@(CPZ<F%W(BP@)&]U=#L*)&-T
M>"T^861D9FEL92@D=&@I.PIC;&]S92`D=&@["B1C86-H95]N86UE(#T@)&-T
M>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#`@+2!L
M96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B7#!#04-(12([
M"FUY("1O9F9S970@/2`D9F@M/G1E;&P@*R!L96YG=&@H)&-A8VAE7VYA;64I
M("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`IP
M86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I"B8F("1F:"T^8VQO<V4*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A
M73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E
M9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!
M4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@
M1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@
M07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF
M9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A
M:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I
M.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@
M(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J
M(#$P,C0I.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*")296%D
M:6YG($U%5$$N>6UL+BXN(BD["FEF("AM>2`D;65T82`]("1Z:7`M/F-O;G1E
M;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.EQS*B0O+VUS
M.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*:68@*&UY("@D8VQE86XI(#T@)&UE
M=&$@/7X@+UY<<RMC;&5A;CH@*"XJ*20O;2D@>PHD8VQE86X@/7X@+UY<<RI\
M7',J)"]G.PHD14Y6>U!!4E]#3$5!3GT@/2`Q(&EF("1C;&5A;CL*?0I]"G!U
M<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@
M=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R
M<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E
M<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB
M97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV
M97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;
M7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N
M86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X
M=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE
M;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@
M(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D
M97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE
M;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X
M=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB
M97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@
M:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S
M86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@
M6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U
M=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY
M("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B
M87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P
M87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I
M;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M
M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R![
M"G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT
M96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I
M<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP
M.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I
M<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I
M;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER
M92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H
M0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#
M=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@
M4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP
M.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P
M='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/
M.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T
M7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%
M3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T
M=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@
M4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z
M7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H
M(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@
M)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I
M;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2![
M"B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I
M;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U
M<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-9
M4U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]
M("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA
M;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!
M3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P
M96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1P<F]G;F%M92(Z("0A73L*<V5E:R`D9F@L("TQ."P@,CL*;7D@
M)&)U9CL*<F5A9"`D9F@L("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%
M(BD@>PIS965K("1F:"P@+34X+"`R.PIR96%D("1F:"P@)&)U9BP@-#$["B1B
M=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?6-A8VAE
M+21B=68B.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@
M1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO
M<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG
M="!R96%D("(D<')O9VYA;64B.B`D(5T["B1C='@M/F%D9&9I;&4H)&9H*3L*
M8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M=&EM93L*)'-T
M;7!D:7(@+CT@(B1S>7-[7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E
M*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER
M("X]("(D<WES>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]
M("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R
M7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O
M;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M
M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M
M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W
M)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L
M;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z
M("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E
M.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M
M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA
M;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[
M4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*
M)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E
M>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M
M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E
M;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@[
M"GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@
M+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS
M<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT
M(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!
M4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R
M;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5]
M(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y
M<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\
M?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM
M?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W
M9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D
M*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D
M<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D
M7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*
M)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI
M<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-
M4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*
M<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@
M(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I
M;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L
M(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV
M;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V
M96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU
M;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A
M<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP
M="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU
M;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H
M)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I
M9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H
M)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`55-%
M4@````!54T523D%-10``````````5$U01$E2``!414U01$E2`%1%35``````
M5$U0```````O=&UP`````'!E<FQX<VDN8P````$;`SOX````'@```'R+__^$
M!0``O(W__Q`!```,CO__)`$``#R.__\X`0``?([__TP!``#,CO__<`$``-R.
M__^$`0``8)___Z@!``!0H/__$`(``.R@__\X`@``<*+__Y@"``#LHO__O`(`
M`.RC___T`@``'*;__T@#``!<IO__:`,``#RG__^<`P``0*?__[`#``!<J?__
M'`0``(RI__\P!```K*K__VP$``!PK___J`0```"P___,!```(+#__^P$``!,
ML?__*`4``*"Q__](!0``W++__[0%``#LL___[`4``("U__\@!@```+W__[@&
M``!LO___[`8``!```````````7I2``1X'@$;#!\`$````!@```"DC/__-```
M``!!!QX0````+````.",__\P`````````!````!`````_(S__SP`````````
M(````%0````HC?__2`````!!#B"=!)X#0I,"3M[=TPX`````$````'@```!4
MC?__!``````````@````C````%"-__^$$````$$.H`5&G52>4P,8!`K=W@X`
M00MD````L````+"=___P`````$$.0)T(G@="DP:4!4*8`9<"1I8#E015UM5!
MV-=#WMW3U`X`00Y`DP:4!94$E@.7`I@!G0B>!T_6U4'8UT'>W=/4#@!!#D"3
M!I0%G0B>!T*7`I@!0MC7`"0````8`0``.)[__Y0`````00ZP`9T6GA5$DQ16
M"M[=TPX`00L```!<````0`$``*R>__^$`0```$$.T`&=&IX92)07DQA$U--(
MWMT.`$$.T`&3&)07G1J>&428$Y<41)85E19S"M330=;50=C700M)T]35UM?8
M0907DQA!EA65%D&8$Y<4```@````H`$``-"?__]T`````$$.()T$G@-"DP)4
MWMW3#@`````T````Q`$``"B@___\`````$(.P"!#G8@$GH<$0Y.&!)2%!$*5
MA`26@P1Q"MW>U=;3U`X`00L``%````#\`0``\*#__RP"````00Y@G0R>"T.3
M"I0)3)4(E@>7!I@%?PK>W=?8U=;3U`X`00M)F@.9!%\*VME!"TG9VD*9!)H#
M0]G:09H#F01"VMD``!P```!0`@``S*+__S@`````00X0G0*>`4;>W0X`````
M,````'`"``#LHO__X`````!"#M!`0YV*")Z)"$.3B`B4APA"E88(;`K=WM73
MU`X`00L``!````"D`@``F*/__P0`````````:````+@"``"(H___'`(```!"
M#N`A0IV<!)Z;!$.3F@24F01#E9@$EI<$70K=WM76T]0.`$$+0IB5!)>6!$N:
MDP29E`1T"MC70=K900M5V-=!VME!EY8$F)4$0=C70IB5!)>6!$&:DP29E`0`
M$````"0#```XI?__*``````````X````.`,``%2E__\8`0```$(.()T$G@-"
MDP)@"M[=TPX`0@M4"M[=TPX`00M#"M[=TPX`0@M##@#3W=XX````=`,``#BF
M___$!````$$.8)T,G@M$E0B6!T*3"I0)19<&F`69!`,:`0K>W=G7V-76T]0.
M`$$+```@````L`,``,"J__^0`````$$.,)T&G@5$DP10"M[=TPX`00L<````
MU`,``"RK__\@`````$$.$)T"G@%&WMT.`````#@```#T`P``+*O__RP!````
M00Y`G0B>!T:3!I0%E026`U@*WMW5UM/4#@!!"TT*WMW5UM/4#@!!"P```!P`
M```P!```'*S__U0`````00X0G0*>`5/>W0X`````.````%`$``!0K/__-`$`
M``!!#D"=")X'1),&E`5"E026`V$*WMW5UM/4#@!!"U,*WMW5UM/4#@!!"P``
M+````(P$``#PA?__)`(```!!#F"=#)X+19,*E`F5")8'`F$*WMW5UM/4#@!!
M"P``-````+P$```@K?__"`$```!!#D"=")X'0Y,&E`5#E026`T.7`I@!8PK>
MW=?8U=;3U`X`00L````P````]`0``/BM__^4`0```$$.0)T(G@=#DP:4!4.5
M!)8#0I<"`E4*WMW7U=;3U`X`00L`E````"@%``!8K___@`<```!"#I"#`D*=
ML"">KR!#EZH@F*D@19.N()2M()6L():K($.9J"":IR!;G*4@FZ8@`FL*W-M!
MW=[9VM?8U=;3U`X`00L"F=O<4MW>V=K7V-76T]0.`$$.D(,"DZX@E*T@E:P@
MEJL@EZH@F*D@F:@@FJ<@FZ8@G*4@G;`@GJ\@`IO;W$&<I2";IB`P````P`4`
M`$"V__]L`@```$$.4)T*G@E#DPB4!T*5!I8%0Y<$`F\*WMW7U=;3U`X`00L`
M$````/0%``!XN/__#```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````)`B````````0"(````````!``````````0#`````````0``
M```````4`P````````$`````````'@,````````,`````````#@;````````
M#0`````````\4P```````!D`````````:/L!```````;``````````@`````
M````&@````````!P^P$``````!P`````````"`````````#U_O]O`````)@"
M````````!0`````````H#0````````8`````````@`,````````*````````
M`)\$````````"P`````````8`````````!4````````````````````#````
M`````(C]`0```````@````````"@!0```````!0`````````!P`````````7
M`````````)@5````````!P````````#X$@````````@`````````H`(`````
M```)`````````!@`````````'@`````````(`````````/O__V\``````0``
M"`````#^__]O`````)@2````````____;P`````"`````````/#__V\`````
MR!$```````#Y__]O`````!``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!0&P``````
M`%`;````````4!L```````!0&P```````%`;````````4!L```````!0&P``
M`````%`;````````4!L```````!0&P```````%`;````````4!L```````!0
M&P```````%`;````````4!L```````!0&P```````%`;````````4!L`````
M``!0&P```````%`;````````4!L```````!0&P```````%`;````````4!L`
M``````!0&P```````%`;````````4!L```````!0&P```````%`;````````
M4!L```````!0&P```````%`;````````4!L```````!0&P```````%`;````
M````4!L```````!0&P```````%`;````````4!L```````!0&P```````%`;
M````````4!L```````!0&P```````%`;````````4!L```````!0&P``````
M`%`;````````4!L```````!0&P```````%`;````````4!L```````!0&P``
M`````%`;````````4!L```````!0&P```````%`;````````4!L```````!0
M&P```````%`;````````4!L```````!X^P$`````````````````````````
M`````````````,10````````````````````````````````````````````
M`````````````````````````````````````````````````'@``@``````
M``````````!`'P``````````````````"``"``````#_____`````+"3````
M````P%,``````````````````+!4````````D),```````"8DP```````*"3
M````````J),``````````````````'B3````````@),`````````````````
M`,A6````````1T-#.B`H56)U;G1U(#$Q+C,N,"TT=6)U;G1U,2D@,3$N,RXP
M```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N
M04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO
M;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT
M97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN
M:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S
M`"YC;VUM96YT````````````````````````````````````````````````
M````````````````````````````````````````"P````$````"````````
M`#@"````````.`(````````;`````````````````````0``````````````
M`````!,````'`````@````````!4`@```````%0"````````)```````````
M``````````0````````````````````F````!P````(`````````>`(`````
M``!X`@```````"`````````````````````$````````````````````-```
M`/;__V\"`````````)@"````````F`(```````#H``````````4`````````
M"````````````````````#X````+`````@````````"``P```````(`#````
M````J`D````````&`````P````@`````````&`````````!&`````P````(`
M````````*`T````````H#0```````)\$```````````````````!````````
M````````````3@```/___V\"`````````,@1````````R!$```````#.````
M``````4``````````@`````````"`````````%L```#^__]O`@````````"8
M$@```````)@2````````8``````````&`````@````@`````````````````
M``!J````!`````(`````````^!(```````#X$@```````*`"````````!0``
M```````(`````````!@`````````=`````0```!"`````````)@5````````
MF!4```````"@!0````````4````5````"``````````8`````````'X````!
M````!@`````````X&P```````#@;````````&`````````````````````0`
M``````````````````!Y`````0````8`````````4!L```````!0&P``````
M`.`#```````````````````0````````````````````A`````$````&````
M`````$`?````````0!\```````#\,P``````````````````0```````````
M`````````(H````!````!@`````````\4P```````#Q3````````%```````
M``````````````0```````````````````"0`````0````(`````````4%,`
M``````!04P```````')````````````````````(````````````````````
MF`````$````"`````````,23````````Q),```````#\````````````````
M````!````````````````````*8````!`````@````````#`E````````,"4
M````````"`8```````````````````@```````````````````"P````#@``
M``,`````````:/L!``````!H^P````````@````````````````````(````
M``````@`````````O`````\````#`````````'#[`0``````</L````````(
M````````````````````"``````````(`````````,@````&`````P``````
M``!X^P$``````'C[````````$`(````````&``````````@`````````$```
M``````#1`````0````,`````````B/T!``````"(_0```````'@"````````
M```````````(``````````@`````````U@````$````#`````````````@``
M```````!``````"`````````````````````"````````````````````-P`
M```(`````P````````"```(``````(```0``````*!``````````````````
M``@```````````````````#A`````0```#````````````````````"```$`
M`````"4````````````````````!``````````$``````````0````,`````
M````````````````````I0`!``````#J`````````````````````0``````
*````````````````
